@@ -5,7 +5,8 @@ from oauthlib.oauth1 import SIGNATURE_TYPE_AUTH_HEADER
 
 from six.moves.urllib_parse import urlencode, unquote
 
-from ..utils import url_add_parameters, parse_qs, handle_http_errors
+from ..utils import url_add_parameters, parse_qs, handle_http_errors, \
+                    constant_time_compare
 from ..exceptions import AuthFailed, AuthCanceled, AuthUnknownError, \
                          AuthMissingParameter, AuthStateMissing, \
                          AuthStateForbidden, AuthTokenError
@@ -87,7 +88,7 @@ class OAuthAuth(BaseAuth):
             raise AuthMissingParameter(self, 'state')
         elif not state:
             raise AuthStateMissing(self, 'state')
-        elif not request_state == state:
+        elif not constant_time_compare(request_state, state):
             raise AuthStateForbidden(self)
         else:
             return state
@@ -385,10 +386,16 @@ class BaseOAuth2(OAuthAuth):
         """Completes login process, must return user instance"""
         self.process_error(self.data)
         state = self.validate_state()
+        data, params = None, None
+        if self.ACCESS_TOKEN_METHOD == 'GET':
+            params = self.auth_complete_params(state)
+        else:
+            data = self.auth_complete_params(state)
 
         response = self.request_access_token(
             self.access_token_url(),
-            data=self.auth_complete_params(state),
+            data=data,
+            params=params,
             headers=self.auth_headers(),
             auth=self.auth_complete_credentials(),
             method=self.ACCESS_TOKEN_METHOD
@@ -404,7 +411,7 @@ class BaseOAuth2(OAuthAuth):
         response = kwargs.get('response') or {}
         response.update(data or {})
         if 'access_token' not in response:
-          response['access_token'] = access_token
+            response['access_token'] = access_token
         kwargs.update({'response': response, 'backend': self})
         return self.strategy.authenticate(*args, **kwargs)
 
